@@ -26,6 +26,12 @@ using namespace Rcpp;
 
 #define SPLIT_CHAR "-"
 
+#define XYUNKNOWN 0
+#define XY        2
+#define XYZ       3
+#define XYM       3
+#define XYZM      4
+
 void addToStream(std::ostringstream& os, Rcpp::String encodedString ) ; 
 
 template<typename Out>
@@ -35,7 +41,7 @@ std::vector<std::string> split(const std::string &s, char delim);
 
 Rcpp::CharacterVector getSfClass(SEXP sf);
 
-Rcpp::DataFrame decode_polyline(std::string encoded);
+Rcpp::DataFrame decode_polyline(std::string encoded, std::string encoded_type);
 
 Rcpp::String EncodeNumber(int num);
 
