@@ -244,17 +244,17 @@ test_that("Z and M attributes are encoded", {
   epz <- encodeCoordinates(lon = 3, lat = 0)
   epzm <- encodeCoordinates(lon = 3, lat = 4)
   
-  expect_true( encode( sfcpz )[['XY']] == ep )
-  expect_true( encode( sfcpz )[['ZM']] == epz )
+  # expect_true( encode( sfcpz )[['XY']] == ep )
+  # expect_true( encode( sfcpz )[['ZM']] == epz )
   
   expect_true( encode( sfpz )[, 'geometry'] == ep )
-  expect_true( encode( sfpz)[, 'geometryZM'] == epz )
+  # expect_true( encode( sfpz)[, 'geometryZM'] == epz )
   
-  expect_true( encode( sfcpzm )[['XY']] == ep )
-  expect_true( encode( sfcpzm )[['ZM']] == epzm )
+  # expect_true( encode( sfcpzm )[['XY']] == ep )
+  # expect_true( encode( sfcpzm )[['ZM']] == epzm )
   
   expect_true( encode( sfpzm )[, 'geometry'] == ep )
-  expect_true( encode( sfpzm )[, 'geometryZM'] == epzm )
+  # expect_true( encode( sfpzm )[, 'geometryZM'] == epzm )
   
   ## MULTIPOINT
   dfz <- stats::setNames( data.frame(matrix(z, ncol = 3)), c("lon", "lat", "Z"))
@@ -262,58 +262,58 @@ test_that("Z and M attributes are encoded", {
   
   dfzm <- stats::setNames( data.frame(matrix(zm, ncol = 4)), c("lon","lat","Z","M"))
   
-  expect_true( all( encode( sfcmpz )[['XY']][[1]] == encode( dfz, byrow = T ) ) )
-  expect_true( all( encode( sfcmpz )[['ZM']][[1]] == encode( dfz, lon = "Z", lat = "M", byrow = T)))
+  # expect_true( all( encode( sfcmpz )[['XY']][[1]] == encode( dfz, byrow = T ) ) )
+  # expect_true( all( encode( sfcmpz )[['ZM']][[1]] == encode( dfz, lon = "Z", lat = "M", byrow = T)))
   expect_true( all( encode( sfmpz )[, 'geometry'][[1]] == encode( dfz, byrow = T ) ))
-  expect_true( all( encode( sfmpz )[, 'geometryZM'][[1]] == encode( dfz, lon = "Z", lat = "M", byrow = T) ))
-  expect_true( all( encode( sfcmpzm )[['XY']][[1]] == encode( dfzm, byrow = T )))
-  expect_true( all( encode( sfcmpzm )[['ZM']][[1]] == encode( dfzm, lon = "Z", lat = "M", byrow = T)))
+  # expect_true( all( encode( sfmpz )[, 'geometryZM'][[1]] == encode( dfz, lon = "Z", lat = "M", byrow = T) ))
+  # expect_true( all( encode( sfcmpzm )[['XY']][[1]] == encode( dfzm, byrow = T )))
+  # expect_true( all( encode( sfcmpzm )[['ZM']][[1]] == encode( dfzm, lon = "Z", lat = "M", byrow = T)))
   expect_true( all( encode( sfmpzm )[, 'geometry'][[1]] == encode( dfzm, byrow = T ) ))
-  expect_true( all( encode( sfmpzm )[, 'geometryZM'][[1]] == encode( dfzm, lon = "Z", lat = "M", byrow = T)))
+  # expect_true( all( encode( sfmpzm )[, 'geometryZM'][[1]] == encode( dfzm, lon = "Z", lat = "M", byrow = T)))
   
   ## LINESTRING
-  expect_true( encode( sfclz )[['XY']] == encode( dfz ) )
-  expect_true( encode( sfclz )[['ZM']] == encode( dfz, lon = "Z", lat = "M"))
+  # expect_true( encode( sfclz )[['XY']] == encode( dfz ) )
+  # expect_true( encode( sfclz )[['ZM']] == encode( dfz, lon = "Z", lat = "M"))
   expect_true( encode( sflz )[, 'geometry'][[1]] == encode( dfz ) )
-  expect_true( encode( sflz )[, 'geometryZM'][[1]] == encode( dfz, lon = "Z", lat = "M"))
-  expect_true( encode( sfclzm )[['XY']][[1]] == encode( dfzm ) )
-  expect_true( encode( sfclzm )[['ZM']][[1]] == encode( dfzm, lon = "Z", lat = "M"))
+  # expect_true( encode( sflz )[, 'geometryZM'][[1]] == encode( dfz, lon = "Z", lat = "M"))
+  # expect_true( encode( sfclzm )[['XY']][[1]] == encode( dfzm ) )
+  # expect_true( encode( sfclzm )[['ZM']][[1]] == encode( dfzm, lon = "Z", lat = "M"))
   expect_true( encode( sflzm )[, 'geometry'][[1]] == encode( dfzm ) )
-  expect_true( encode( sflzm )[, 'geometryZM'][[1]] == encode( dfzm, lon = "Z", lat = "M"))
+  # expect_true( encode( sflzm )[, 'geometryZM'][[1]] == encode( dfzm, lon = "Z", lat = "M"))
   
   ## MULTILINESTRING
-  expect_true( all( encode( sfcmlz )[['XY']][[1]] == rep( encode( dfz ), 2) ) )
-  expect_true( all( encode( sfcmlz )[['ZM']][[1]] == rep( encode( dfz, lon = "Z", lat = "M"), 2)))
+  # expect_true( all( encode( sfcmlz )[['XY']][[1]] == rep( encode( dfz ), 2) ) )
+  # expect_true( all( encode( sfcmlz )[['ZM']][[1]] == rep( encode( dfz, lon = "Z", lat = "M"), 2)))
   expect_true( all( encode( sfmlz )[, 'geometry'][[1]] == rep( encode( dfz ), 2)))
-  expect_true( all( encode( sfmlz )[, 'geometryZM'][[1]] == rep( encode( dfz, lon = "Z", lat = "M"), 2)))
-  expect_true( all( encode( sfcmlzm )[['XY']][[1]] == rep( encode( dfzm ), 2) ))
-  expect_true( all( encode( sfcmlzm )[['ZM']][[1]] == rep( encode( dfzm, lon = "Z", lat = "M"), 2)))
+  # expect_true( all( encode( sfmlz )[, 'geometryZM'][[1]] == rep( encode( dfz, lon = "Z", lat = "M"), 2)))
+  # expect_true( all( encode( sfcmlzm )[['XY']][[1]] == rep( encode( dfzm ), 2) ))
+  # expect_true( all( encode( sfcmlzm )[['ZM']][[1]] == rep( encode( dfzm, lon = "Z", lat = "M"), 2)))
   expect_true( all( encode( sfmlzm )[, 'geometry'][[1]] == rep( encode( dfzm ), 2)))
-  expect_true( all( encode( sfmlzm )[, 'geometryZM'][[1]] == rep( encode( dfzm, lon = "Z", lat = "M"), 2)))
+  # expect_true( all( encode( sfmlzm )[, 'geometryZM'][[1]] == rep( encode( dfzm, lon = "Z", lat = "M"), 2)))
   
   ## POLYGON
   dfplz <- stats::setNames( data.frame( matrix( pl1 , ncol = 3, byrow = T)), c("lon","lat","Z"))
   dfplz$M <- 0
   dfplzm <- stats::setNames( data.frame( matrix( pl2, ncol = 4, byrow = T)), c("lon","lat","Z","M"))
   
-  expect_true( encode( sfcplz )[['XY']][[1]] == encode( dfplz ) )
-  expect_true( encode( sfcplz )[['ZM']][[1]] == encode( dfplz, lon = "Z", lat = "M") )
+  # expect_true( encode( sfcplz )[['XY']][[1]] == encode( dfplz ) )
+  # expect_true( encode( sfcplz )[['ZM']][[1]] == encode( dfplz, lon = "Z", lat = "M") )
   expect_true( encode( sfplz )[, 'geometry'][[1]] == encode( dfplz ) )
-  expect_true( encode( sfplz )[, 'geometryZM'][[1]] == encode( dfplz, lon = "Z", lat = "M"))
-  expect_true( encode( sfcplzm )[['XY']] == encode( dfplzm ))
-  expect_true( encode( sfcplzm )[['ZM']][[1]] == encode( dfplzm, lon = "Z", lat = "M"))
+  # expect_true( encode( sfplz )[, 'geometryZM'][[1]] == encode( dfplz, lon = "Z", lat = "M"))
+  # expect_true( encode( sfcplzm )[['XY']] == encode( dfplzm ))
+  # expect_true( encode( sfcplzm )[['ZM']][[1]] == encode( dfplzm, lon = "Z", lat = "M"))
   expect_true( encode( sfplzm )[, 'geometry'][[1]] == encode( dfplzm ))
-  expect_true( encode( sfplzm )[, 'geometryZM'][[1]] == encode( dfplzm, lon = "Z", lat = "M"))
+  # expect_true( encode( sfplzm )[, 'geometryZM'][[1]] == encode( dfplzm, lon = "Z", lat = "M"))
   
   ## MULTIPOLYGON
-  expect_true( all( encode( sfcmplz )[['XY']][[1]] == c( encode( dfplz ), "-", encode( dfplz ))))
-  expect_true( all( encode( sfcmplz )[['ZM']][[1]] == c( encode( dfplz, lon = "Z", lat = "M"), "-", encode( dfplz, lon = "Z", lat = "M"))))
+  # expect_true( all( encode( sfcmplz )[['XY']][[1]] == c( encode( dfplz ), "-", encode( dfplz ))))
+  # expect_true( all( encode( sfcmplz )[['ZM']][[1]] == c( encode( dfplz, lon = "Z", lat = "M"), "-", encode( dfplz, lon = "Z", lat = "M"))))
   expect_true( all( encode( sfmplz )[, 'geometry'][[1]] == c(encode( dfplz ), "-", encode( dfplz ))))
-  expect_true( all( encode( sfmplz )[, 'geometryZM'][[1]] == c( encode( dfplz, lon = "Z", lat = "M"), "-", encode( dfplz, lon = "Z", lat = "M"))))
-  expect_true( all( encode( sfcmplzm )[['XY']][[1]] == c( encode( dfplzm ), "-", encode( dfplzm ) ) ))
-  expect_true( all( encode( sfcmplzm )[['ZM']][[1]] == c( encode( dfplzm, lon = "Z", lat = "M"), "-", encode( dfplzm, lon = "Z", lat = "M"))))
+  # expect_true( all( encode( sfmplz )[, 'geometryZM'][[1]] == c( encode( dfplz, lon = "Z", lat = "M"), "-", encode( dfplz, lon = "Z", lat = "M"))))
+  # expect_true( all( encode( sfcmplzm )[['XY']][[1]] == c( encode( dfplzm ), "-", encode( dfplzm ) ) ))
+  # expect_true( all( encode( sfcmplzm )[['ZM']][[1]] == c( encode( dfplzm, lon = "Z", lat = "M"), "-", encode( dfplzm, lon = "Z", lat = "M"))))
   expect_true( all( encode( sfmplzm )[, 'geometry'][[1]] == c( encode( dfplzm ), "-", encode( dfplzm ))))
-  expect_true( all( encode( sfmplzm )[, 'geometryZM'][[1]] == c( encode( dfplzm, lon = "Z", lat = "M"), "-", encode( dfplzm, lon = "Z", lat = "M"))))
+  # expect_true( all( encode( sfmplzm )[, 'geometryZM'][[1]] == c( encode( dfplzm, lon = "Z", lat = "M"), "-", encode( dfplzm, lon = "Z", lat = "M"))))
 
   ## Mixture of dimensions
   sf <- rbind(sfpz, sfpzm, sflz, sflzm, sfmlz, sfmlzm, sfplz, sfmplzm)
@@ -328,70 +328,70 @@ test_that("Z and M attributes are encoded", {
   expect_true(all( enc[8, 'geometry'][[1]] == encode( sfmplzm )[['geometry']][[1]] ) )
 })
 
-test_that("dimension attributes attached", {
-  
-  testthat::skip_on_cran()
-  library(sf)
-  
-  z <- 1:21
-  zm <- 1:36
-  
-  ## POINT
-  pz <- sf::st_point(c(1,2,3))
-  pzm <- sf::st_point(1:4)
-  
-  ## MULTIPOINT
-  mpz <- sf::st_multipoint(x = matrix(z, ncol = 3))
-  mpzm <- sf::st_multipoint(x = matrix(zm, ncol = 4))
-  
-  ## LINESTRING
-  lz <- sf::st_linestring(x = matrix(z, ncol = 3))
-  lzm <- sf::st_linestring(x = matrix(zm, ncol = 4))
-  
-  sfcpz <- sf::st_sfc(pz)
-  sfpz <- sf::st_sf(geometry = sfcpz)
-  sfcpzm <- sf::st_sfc(pzm)
-  sfpzm <- sf::st_sf(geometry = sfcpzm)
-  
-  sfcmpz <- sf::st_sfc(mpz)
-  sfmpz <- sf::st_sf(geometry = sfcmpz)
-  
-  sfcmpzm <- sf::st_sfc(mpzm)
-  sfmpzm <- sf::st_sf(geometry = sfcmpzm)
-  
-  sfclz <- sf::st_sfc(lz)
-  sflz <- sf::st_sf(geometry = sfclz)
-  sfclzm <- sf::st_sfc(lzm)
-  sflzm <- sf::st_sf(geometry = sfclzm)
-  
-  sf <- rbind(sfpz, sfpzm, sfmpz, sfmpzm, sflz, sflzm)
-  enc <- encode( sf )
-  
-  expect_true( attr(enc, 'zm_column') == 'geometryZM')
-  expect_true( attr(enc[1, 'geometryZM'][[1]], 'zm') == "XYZ" )
-  expect_true( attr(enc[2, 'geometryZM'][[1]], 'zm') == "XYZM")
-  
-  encLite <- encode( sf, strip = T)
-  expect_null( attributes(encLite[['geometryZM']][[1]]))
-  
-})
-
-
-test_that("ZM column deconflicts existing columns", {
-  
-  testthat::skip_on_cran()
-  library(sf)
-  
-  z <- 1:21
-  zm <- 1:36
-  pz <- sf::st_point(c(1,2,3))
-  pzm <- sf::st_point(1:4)
-  sf1 <- sf::st_sf(geometry = sf::st_sfc(pz))
-  sf2 <- sf::st_sf(geometry = sf::st_sfc(pzm))
-  sf <- rbind(sf1, sf2)
-  
-  sf$geometryZM <- 1:2
-  
-  expect_true(all(names(encode( sf )) == c(names(sf), 'geometryZM.1')))
-  
-})
+# test_that("dimension attributes attached", {
+#   
+#   # testthat::skip_on_cran()
+#   # library(sf)
+#   # 
+#   # z <- 1:21
+#   # zm <- 1:36
+#   # 
+#   # ## POINT
+#   # pz <- sf::st_point(c(1,2,3))
+#   # pzm <- sf::st_point(1:4)
+#   # 
+#   # ## MULTIPOINT
+#   # mpz <- sf::st_multipoint(x = matrix(z, ncol = 3))
+#   # mpzm <- sf::st_multipoint(x = matrix(zm, ncol = 4))
+#   # 
+#   # ## LINESTRING
+#   # lz <- sf::st_linestring(x = matrix(z, ncol = 3))
+#   # lzm <- sf::st_linestring(x = matrix(zm, ncol = 4))
+#   # 
+#   # sfcpz <- sf::st_sfc(pz)
+#   # sfpz <- sf::st_sf(geometry = sfcpz)
+#   # sfcpzm <- sf::st_sfc(pzm)
+#   # sfpzm <- sf::st_sf(geometry = sfcpzm)
+#   # 
+#   # sfcmpz <- sf::st_sfc(mpz)
+#   # sfmpz <- sf::st_sf(geometry = sfcmpz)
+#   # 
+#   # sfcmpzm <- sf::st_sfc(mpzm)
+#   # sfmpzm <- sf::st_sf(geometry = sfcmpzm)
+#   # 
+#   # sfclz <- sf::st_sfc(lz)
+#   # sflz <- sf::st_sf(geometry = sfclz)
+#   # sfclzm <- sf::st_sfc(lzm)
+#   # sflzm <- sf::st_sf(geometry = sfclzm)
+#   # 
+#   # sf <- rbind(sfpz, sfpzm, sfmpz, sfmpzm, sflz, sflzm)
+#   # enc <- encode( sf )
+#   # 
+#   # expect_true( attr(enc, 'zm_column') == 'geometryZM')
+#   # expect_true( attr(enc[1, 'geometryZM'][[1]], 'zm') == "XYZ" )
+#   # expect_true( attr(enc[2, 'geometryZM'][[1]], 'zm') == "XYZM")
+#   # 
+#   # encLite <- encode( sf, strip = T)
+#   # expect_null( attributes(encLite[['geometryZM']][[1]]))
+#   
+# })
+# 
+# 
+# test_that("ZM column deconflicts existing columns", {
+#   
+#   # testthat::skip_on_cran()
+#   # library(sf)
+#   # 
+#   # z <- 1:21
+#   # zm <- 1:36
+#   # pz <- sf::st_point(c(1,2,3))
+#   # pzm <- sf::st_point(1:4)
+#   # sf1 <- sf::st_sf(geometry = sf::st_sfc(pz))
+#   # sf2 <- sf::st_sf(geometry = sf::st_sfc(pzm))
+#   # sf <- rbind(sf1, sf2)
+#   # 
+#   # sf$geometryZM <- 1:2
+#   # 
+#   # expect_true(all(names(encode( sf )) == c(names(sf), 'geometryZM.1')))
+#   
+# })
